@@ -13,6 +13,7 @@
 
 
 mod_FCR_model_box_ui <- function(id){
+HTML <- NULL
   ns <- NS(id)
   tagList(
     tags$div(id = id,
@@ -77,6 +78,7 @@ tags$div(HTML("<script type='text/x-mathjax-config' >
 #' 
 
 #globalVariables(c("HTML","ID","value","variable","x","y")) 
+value <- NULL
 mod_FCR_model_box_server <- function(id, raw_data, id_col, time_col,dark_mode){
   moduleServer( id, function(input, output, session){
     ns <- session$ns
